globals [
  feeding-troughs
  mean-total-bites            ;; to present the percentage of bites from total behaviours
  mean-total-movements
  mean-total-feedings
  mean-total-explorations
  mean-total-restings
  mean-total-sleepings
]

turtles-own [
  feeding-drive ;; the drive to feed
  sleeping-drive ;; the drive to sleep
  exploration-drive ;; the drive to explore
  biting-drive  ;; the drive to bite a tail
  movements     ;; how often the pig performed the move behaviour
  feedings      ;; how often the pig performed the feeding behaviour
  explorations  ;; how often the pig performed the exploration behaviour
  restings      ;; how often the pig performed the resting behaviour
  sleepings     ;; how often the pig performed the sleeping behaviour
  bites         ;; how often the pig has been biting in someone else's tail
  bitten        ;; how often the pig has been bitten in its own tail
  biting-threshold
  inactive-state
]

breed [pigs]

to setup
  clear-all
  if generate-seed? [set Seed-for-random new-seed]
  random-seed Seed-for-random
  setup-patches
  setup-turtles
  reset-ticks
end

to setup-patches
  ask patches [
  set pcolor grey
  set feeding-troughs patches with [pxcor = 0 and pycor >= min-pycor and pycor <= max-pycor]
  ask feeding-troughs [ set pcolor black ]
  ]
end

to setup-turtles
  set-default-shape turtles "pig"
  create-turtles number-of-pigs [ setxy random-xcor random-ycor ]
  ask turtles [
    set color pink + 1
    set size 2
    ifelse Variation-TB-threshold? [
      set biting-threshold random-normal biting-level-general Variation-threshold ; individual variation between pigs in threshold for tail biting
    ][
      set biting-threshold biting-level-general ; all pigs have the same threshold level for tail biting
    ]
    set biting-drive       0
    set feeding-drive      random-normal -0.4 0.10
    set sleeping-drive     random-normal 0 0.10
    set exploration-drive  random-normal 0 0.10
    face min-one-of turtles [distance myself]
    back 0.4
    set heading random 360
  ]
end

to go
  if ticks >= end-simulation [stop]
  ask turtles [
    ifelse feeding-drive < 0 and sleeping-drive < 0 and exploration-drive < 0 and biting-drive < biting-threshold[
      let x random-float 100
        ifelse x < 14
        [ move ]
        [ rest ]
    ][
    let deviation-feeding     0 - feeding-drive
    let deviation-sleeping    0 - sleeping-drive
    let deviation-exploration 0 - exploration-drive
    let deviation-biting      biting-threshold - biting-drive
    let motivation-list ( list deviation-feeding deviation-sleeping deviation-exploration deviation-biting)
    let highest-motivation min motivation-list

      ifelse deviation-feeding = highest-motivation
      [eat]
      [ ifelse deviation-sleeping = highest-motivation
        [sleep]
        [ ifelse deviation-exploration = highest-motivation
          [try-to-explore]
          [bite-tail]
        ]
      ]
    ]
  ]
  check-total-behaviours
  check-color
  tick
end

to move                   ;; a pig only moves (or rests) if all states are neutral
   move-to one-of patches
   set heading random 360
   face min-one-of turtles [distance myself]
   back 0.4
   rt 3
   set feeding-drive feeding-drive + Feeding-drive-gain-high
   set sleeping-drive sleeping-drive + Sleep-drive-gain-high
   set exploration-drive exploration-drive + Expl-drive-gain-high
   set movements movements + 1
   set inactive-state false
end

to eat
     move-to one-of feeding-troughs
     set feeding-drive feeding-drive - Feeding-drive-decrease
     set exploration-drive exploration-drive + Expl-drive-gain-low
     set feedings feedings + 1
   set sleeping-drive sleeping-drive + Sleep-drive-gain-high
   move-to one-of patches
   set heading random 360
   face min-one-of turtles [distance myself]
   back 0.4
   rt 3
   set inactive-state false
end

to try-to-explore
   right random 360
   if can-move? 2 [fd random 2]
   face min-one-of turtles [distance myself]
   back 0.4
   rt 3
   set feeding-drive feeding-drive + Feeding-drive-gain-high
   set biting-drive biting-drive + Biting-drive-gain-high  ;; exploring fails due to lack of enrichment
   set sleeping-drive sleeping-drive + Sleep-drive-gain-high
   set exploration-drive exploration-drive - 0
   set explorations explorations + 1
   set inactive-state false
end

to bite-tail
  ifelse victim-lying? [
   let victim-tired-neighbor min-one-of other turtles with [inactive-state = true] [distance myself]
      ifelse victim-tired-neighbor != nobody [   ;; if lying pigs, select nearest lying pig
       move-to victim-tired-neighbor
         ask victim-tired-neighbor [
           set bitten bitten + 1
           if impact-victim? [
            set biting-drive biting-drive + Biting-drive-gain-low
            set sleeping-drive sleeping-drive - Sleeping-drive-decrease  ;; when being bitten they become more active (so they get extra awake)
            if can-move? 1 [fd 0.5]  ;; only move a bit in reaction on a bite
            ]
         ]
      ][
       let victim-closest-neighbor min-one-of other turtles [distance myself]  ;; if not somebody lying, go to nearest pig
       face victim-closest-neighbor
       move-to victim-closest-neighbor
         ask victim-closest-neighbor [
            set bitten bitten + 1
            if impact-victim? [
            set biting-drive biting-drive + Biting-drive-gain-low
            set sleeping-drive sleeping-drive - Sleeping-drive-decrease  ;; when being bitten they become more active (so they get extra awake)
            if can-move? 1 [fd 0.5]  ;; only move a bit in reaction on a bite
            ]
         ]
      ]
  ][
  let victim-closest-neighbor min-one-of other turtles [distance myself]  ;; if not aiming at a lying pig, go to nearest pig
       face victim-closest-neighbor
       move-to victim-closest-neighbor
         ask victim-closest-neighbor [
            set bitten bitten + 1
            if impact-victim? [
            set biting-drive biting-drive + Biting-drive-gain-low
            set sleeping-drive sleeping-drive - Sleeping-drive-decrease  ;; when being bitten they become more active (so they get extra awake)
            if can-move? 1 [fd 0.5]  ;; only move a bit in reaction on a bite
            ]
         ]
  ]
     set bites bites + 1
     set biting-drive biting-drive -  Biting-drive-decrease
     set feeding-drive feeding-drive + Feeding-drive-gain-high
     set sleeping-drive sleeping-drive + Sleep-drive-gain-high
     set exploration-drive exploration-drive - Expl-drive-decrease
     move-to one-of patches
     set inactive-state false
end

to rest       ;; a pig only rests (or moves) if all states are neutral
   let closest-neighbor min-one-of other turtles [distance myself]
   face closest-neighbor
   move-to closest-neighbor
   fd -0.5
   set feeding-drive feeding-drive + Feeding-drive-gain-low
   set sleeping-drive sleeping-drive + Sleep-drive-gain-low
   set exploration-drive exploration-drive + Expl-drive-gain-high
   set restings restings + 1
   set inactive-state true
end

to sleep
   let most-tired-pig max-one-of other turtles [sleeping-drive]
   move-to most-tired-pig
   fd -0.5
   right random 360
   set feeding-drive feeding-drive + Feeding-drive-gain-low
   set exploration-drive exploration-drive - Expl-drive-decrease
   set sleeping-drive sleeping-drive - 0.20 ; Sleeping-drive-decrease (temporarily replaced by number for doing the SA on effect impact victim)
   if biting-drive > 0 [set biting-drive biting-drive - Biting-drive-decrease ]
   set sleepings sleepings + 1
   set inactive-state true
end

to check-total-behaviours
  let total-bites           sum [bites] of turtles
  let total-movements       sum [movements] of turtles
  let total-feedings        sum [feedings] of turtles
  let total-explorations    sum [explorations] of turtles
  let total-restings        sum [restings] of turtles
  let total-sleepings       sum [sleepings] of turtles
  let total-all total-bites + total-movements + total-feedings + total-explorations + total-restings + total-sleepings
  set mean-total-bites           100 * total-bites / total-all
  set mean-total-feedings        100 * total-feedings / total-all
  set mean-total-explorations    100 * total-explorations / total-all
  set mean-total-restings        100 * total-restings / total-all
  set mean-total-sleepings       100 * total-sleepings / total-all
  set mean-total-movements       100 * total-movements / total-all
end

to check-color
  ask turtles [
    if bites > 0 and bitten = 0 [ set color red ]       ;; a biter colors red
    if bites = 0 and bitten > 0 [ set color blue ]      ;; a victim colors violet -2
    if bites > 0 and bitten > 0 [ set color 123 ]       ;; if both a biter and victim the pig colors magenta -2
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
172
10
542
401
-1
-1
72.0
1
10
1
1
1
0
0
0
1
0
4
0
4
1
1
1
ticks
30.0

BUTTON
0
159
55
192
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
56
159
111
192
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

PLOT
548
156
1159
276
Pigs getting motivated to bite (no)
time
totals
0.0
10.0
0.0
10.0
true
true
"" "if ticks > 1000\n[\n  set-plot-x-range (ticks - 1000) ticks                                       \n]"
PENS
"General" 1.0 0 -955883 true "" "plot count turtles with [biting-drive > (biting-threshold - (biting-drive * 0.3))]"

SLIDER
-1
114
137
147
Number-of-pigs
Number-of-pigs
2
50
10
1
1
NIL
HORIZONTAL

BUTTON
112
159
167
192
Go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
299
525
613
645
# of biters and victims
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Biters" 1.0 0 -2674135 true "" "plot count turtles with [bites > 0 and bitten = 0]"
"Victims" 1.0 0 -13345367 true "" "plot count turtles with [bites = 0 and bitten > 0]"
"Biters & victims" 1.0 0 -10022847 true "" "plot count turtles with [bites > 0 and bitten > 0]"
"Neutral" 1.0 0 -1264960 true "" "plot count turtles with [bites = 0 and bitten = 0]"

PLOT
548
10
1159
156
Mean levels of states
NIL
NIL
0.0
10.0
-0.5
0.5
true
true
"" "if ticks > 1000\n[\n  set-plot-x-range (ticks - 1000) ticks                                       \n]"
PENS
"Feeding drive" 1.0 0 -13840069 true "" "plot mean [feeding-drive] of turtles"
"Sleeping drive" 1.0 0 -1184463 true "" "plot mean [sleeping-drive] of turtles"
"Exploring drive" 1.0 0 -8630108 true "" "plot mean [exploration-drive] of turtles"
"Biting drive" 1.0 0 -2674135 true "" "plot mean [biting-drive] of turtles"

PLOT
10
525
294
645
Total # of bites
NIL
NIL
0.0
10.0
0.0
30.0
true
true
"" ""
PENS
"Total bites" 1.0 0 -16777216 true "" "plot sum [bites] of turtles"

SLIDER
154
413
314
446
Feeding-drive-decrease
Feeding-drive-decrease
0.6
2
1.11
0.01
1
NIL
HORIZONTAL

SLIDER
154
450
313
483
Feeding-drive-gain-low
Feeding-drive-gain-low
0.01
0.2
0.09
0.01
1
NIL
HORIZONTAL

SLIDER
154
482
313
515
Feeding-drive-gain-high
Feeding-drive-gain-high
0.01
0.49
0.18
0.01
1
NIL
HORIZONTAL

SLIDER
315
413
484
446
Sleeping-drive-decrease
Sleeping-drive-decrease
0.15
0.5
0.2
0.01
1
NIL
HORIZONTAL

SLIDER
315
450
483
483
Sleep-drive-gain-low
Sleep-drive-gain-low
0.01
0.3
0.17
0.01
1
NIL
HORIZONTAL

SLIDER
315
482
483
515
Sleep-drive-gain-high
Sleep-drive-gain-high
0.1
0.5
0.21
0.01
1
NIL
HORIZONTAL

SLIDER
485
413
637
446
Expl-drive-decrease
Expl-drive-decrease
0.08
0.5
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
485
450
637
483
Expl-drive-gain-low
Expl-drive-gain-low
0.01
0.12
0.05
0.01
1
NIL
HORIZONTAL

SLIDER
485
482
637
515
Expl-drive-gain-high
Expl-drive-gain-high
0.1
0.45
0.17
0.01
1
NIL
HORIZONTAL

SLIDER
-1
338
167
371
Biting-level-general
Biting-level-general
0
1.5
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
1
413
150
446
Biting-drive-decrease
Biting-drive-decrease
0.0
1
0.09
0.01
1
NIL
HORIZONTAL

SLIDER
1
482
149
515
Biting-drive-gain-high
Biting-drive-gain-high
0.01
0.5
0.276
0.001
1
NIL
HORIZONTAL

MONITOR
638
409
706
454
% sleepings
mean-total-sleepings
2
1
11

MONITOR
638
456
706
501
% restings
mean-total-restings
2
1
11

MONITOR
639
504
736
549
% explorations
mean-total-explorations
2
1
11

MONITOR
639
552
707
597
% feedings
mean-total-feedings
2
1
11

MONITOR
639
599
732
644
% movements
mean-total-movements
2
1
11

SLIDER
0
194
167
227
end-simulation
end-simulation
1
1440
720
1
1
NIL
HORIZONTAL

MONITOR
735
504
792
549
% bites
mean-total-bites
3
1
11

SWITCH
1
10
137
43
Generate-seed?
Generate-seed?
0
1
-1000

INPUTBOX
0
43
137
103
Seed-for-random
1419344149
1
0
Number

PLOT
548
275
1159
407
Behavioural time budget of pigs (%)
NIL
NIL
0.0
1.0
0.0
0.5
true
true
"" ""
PENS
"sleeping" 1.0 0 -1184463 true "" "plot mean-total-sleepings"
"restings" 1.0 0 -408670 true "" "plot mean-total-restings"
"feedings" 1.0 0 -13840069 true "" "plot mean-total-feedings"
"movements" 1.0 0 -3844592 true "" "plot mean-total-movements"
"explorations" 1.0 0 -8630108 true "" "plot mean-total-explorations"

SLIDER
1
450
149
483
Biting-drive-gain-low
Biting-drive-gain-low
0
1
0.05
0.05
1
NIL
HORIZONTAL

PLOT
798
422
1158
551
Mean biting drive of pigs
NIL
NIL
0.0
10.0
-0.1
0.35
true
true
"" ""
PENS
"Mean group" 1.0 0 -16777216 true "" "plot mean [biting-drive] of turtles"
"Pig 1" 1.0 0 -7500403 true "" "plot [biting-drive] of turtle 1"

SWITCH
0
236
167
269
Impact-victim?
Impact-victim?
1
1
-1000

SWITCH
0
306
167
339
Variation-TB-threshold?
Variation-TB-threshold?
1
1
-1000

MONITOR
798
555
870
600
Total bites
sum [bites] of turtles
17
1
11

SWITCH
1
269
166
302
Victim-lying?
Victim-lying?
1
1
-1000

SLIDER
-1
371
167
404
Variation-threshold
Variation-threshold
0
1
0.05
0.01
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This model simulates the behaviour of pigs housed in a barren conventional pen. Tail biting patterns can emerge based on internal motivation of pigs to bite when exploratory needs cannot be fulfilled. In the reference setting, motivation to bite tails was the only factor causing tail biting behaviour. Two additional factors, preference for biting the tail of a lying pig (see switch victim-lying?) and behavioural change in victims (see switch change-victim?), could be simulated optional.

## HOW IT WORKS

Pigs have four internal states: feeding drive, sleeping drive, biting drive and exploration drive. Each time step, pigs (in a random order) check their internal states. When an internal state is above a threshold, pigs become motivated to perform the behaviour related to the internal state (eating, exploring, sleeping or tail biting). If pigs are not motivated, they will randomly move or rest.

A pig that performs tail biting behaviour will select a victim: the closest pig (in reference setting) or a nearby lying pig as a victim (if PREF was included). Pigs in the model all start as neutral (pink) pigs, but can change into a biter (red), victim (blue), or both biter and victim (magenta).

## HOW TO USE IT

Click the 'Setup' button to set up the pen and number of pigs in the pen as indicated by the slider. The number of pigs in a pen (number-of-pigs) can be changed before setup.
Click the 'Go' button to start the simulation.

The output of the model shows:
•	a visual view of the pigs in their environment and their status (neutral, victim, biter or both biter and victim) in skin colour
•	the mean group level of different internal states (plotted each tick)
•	the number of pigs that is 30% away from getting frustrated (which means that they almost reached  the biting level at the point that they are going to bite)
•	the percentage of specific behaviours performed during the run on average
•	the development of transitions of pigs that remained neutral or changed into a biter, victim or both biter and victim
•	the development in number of tail bites.

## THINGS TO TRY

Test the effect of:

- behavioural change in a victim (switch change-victim?)
- preference for biting a lying pig (switch lying-victim?
- pig density (change the number of pigs)
- variation in biting threshold level among pigs (switch variation-TB-threshold & variation-threshold value)
- different levels of costs and gains of states (e.g. lower feeding-drive-gain assuming feed that contains a lower energy value)

## REFERENCES

Boumans, I.J.M.M., Hofstede, G.J., Bolhuis, J.E., de Boer, I.J.M., Bokkers, E.A.M. (in press). Agent-based modelling in applied ethology: An exploratory case study of behavioural dynamics in tail biting in pigs. Appl Anim Behav Sci.

## CONTACT AND CREDITS

This project was created in 2016 in the PhD project: Pig behavior and related sustainability performance in novel farm designs: an agent-based approach

Author:
Iris J.M.M. Boumans
Animal Production Systems group
Wageningen University
P.O. Box 388
6700 AH Wageningen
The Netherlands

E-mail: Iris.Boumans@wur.nl
www.wageningenur.nl/aps

Many thanks to Gert Jan Hofstede, Mark Kramer and Sjoukje Osinga for their support during development of the model.





@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

pig
true
0
Circle -7500403 true true 117 155 67
Circle -7500403 true true 116 162 67
Circle -7500403 false true 135 231 18
Circle -7500403 false true 138 227 14
Circle -16777216 true false 142 114 4
Circle -16777216 true false 141 113 6
Circle -16777216 true false 154 112 6
Circle -7500403 true true 96 156 108
Circle -7500403 true true 108 59 80
Circle -7500403 true true 96 142 108
Circle -7500403 true true 96 117 108
Circle -7500403 true true 96 96 108
Circle -7500403 true true 131 43 34
Circle -5825686 true false 107 81 31
Circle -5825686 true false 156 80 31
Rectangle -5825686 true false 107 93 126 112
Rectangle -5825686 true false 172 94 188 110
Circle -16777216 true false 131 69 10
Circle -16777216 true false 151 68 10
Circle -7500403 false true 139 263 22
Circle -7500403 false true 139 263 22
Circle -7500403 false true 139 263 22
Circle -7500403 false true 138 257 22
Circle -7500403 false true 141 254 22

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
